@@ -66,7 +66,7 @@ sub check_kwalitee
 
 =cut
 
-sub cpants_lint { "cpants_lint.pl" }
+sub cpants_lint { $^O eq 'MSWin32' ? 'cpants_lint.bat' : 'cpants_lint.pl' }
 
 =item cpants_pass_regex
 
@@ -91,11 +91,11 @@ This source is in GitHub
 
 =head1 AUTHOR
 
-brian d foy, C<< <bdfoy@cpan.org> >>
+brian d foy, C<< <briandfoy@pobox.com> >>
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright © 2007-2023, brian d foy C<< <bdfoy@cpan.org> >>. All rights reserved.
+Copyright © 2007-2024, brian d foy C<< <briandfoy@pobox.com> >>. All rights reserved.
 
 This program is free software; you can redistribute it and/or modify
 it under the Artistic License 2.0.
